Module bytes_codec

Module bytes_codec 

Functions

read_bytes
read_bytes_header
Reads the header of the bytes data in Solidity or WASM compatible format Returns the offset and size of the data
read_bytes_header_solidity
Reads the header of a Solidiof the data
read_bytes_header_wasm
write_bytes
Universal function to write bytes in Solidity or WASM compatible format
write_bytes_solidity
Write bytes in Solidity compatible format
write_bytes_wasm
Write bytes in WASM compatible format