read_bytes_header

Function read_bytes_header 

pub fn read_bytes_header<B: ByteOrder, const ALIGN: usize, const SOL_MODE: bool>(
    buf: &impl Buf,
    offset: usize,
) -> Result<(usize, usize), CodecError>
Reads the header of the bytes data in Solidity or WASM compatible format Returns the offset and size of the data