Module encoder

Module encoder 

Structs

CompactABI
SolidityABI
SolidityPackedABI

Traits

Encoder
Trait for encoding and decoding values with specific byte order, alignment, and mode.
FluentEncoder
SolidityEncoder
SolidityPackedEncoder

Functions

align_up
Rounds up the given offset to the nearest multiple of ALIGN. ALIGN must be a power of two.
ensure_buf_size
Ensure the buffer is large enough to hold the data
is_big_endian
Checks if the given byte order is big-endian.
is_dynamic
Checks if the given type is dynamic.
read_u32_aligned
write_u32_aligned