Functions
- read_
bytes - read_
bytes_ header - Reads the header of the bytes data in Solidity or WASM compatible format Returns the offset and size of the data
- read_
bytes_ header_ solidity - Reads the header of a Solidiof the data
- read_
bytes_ header_ wasm - write_
bytes - Universal function to write bytes in Solidity or WASM compatible format
- write_
bytes_ solidity - Write bytes in Solidity compatible format
- write_
bytes_ wasm - Write bytes in WASM compatible format