Structs
Traits
- Encoder
- Trait for encoding and decoding values with specific byte order, alignment, and mode.
- Fluent
Encoder - Solidity
Encoder - Solidity
Packed Encoder
Functions
- align_
up - Rounds up the given offset to the nearest multiple of ALIGN. ALIGN must be a power of two.
- ensure_
buf_ size - Ensure the buffer is large enough to hold the data
- is_
big_ endian - Checks if the given byte order is big-endian.
- is_
dynamic - Checks if the given type is dynamic.
- read_
u32_ aligned - write_
u32_ aligned